@@ -18,16 +18,40 @@
 #'   set of PLS axes is optionally displayed, and thin-plate spline deformation grids along these axes are also shown if data were 
 #'   input as a 3D array.  
 #'   
-#'   Input for the analysis can take one of two forms. First, one can input a single dataset (as a matrix or 3D array, along with 
+#'  Input for the analysis can take one of two forms. First, one can input a single dataset (as a matrix or 3D array, along with 
 #'  a vector describing which variables correspond to which partitions (for the case of a 3D array, which landmarks belong to which 
 #'  partitions is specified). Alternatively, when evaluating the integration between two structures or partitions, two datasets may be provided.
 #'
-#'  The generic functions, \code{\link{print}}, \code{\link{summary}}, and \code{\link{plot}} all work with \code{\link{modularity.test}}.
+#'  The generic functions, \code{\link{print}}, \code{\link{summary}}, and \code{\link{plot}} all work with \code{\link{integration.test}}.
 #'  The generic function, \code{\link{plot}}, produces a two-block.pls plot.  This function calls \code{\link{plot.pls}}, which has two additional
 #'  arguments (with defaults): label = NULL, warpgrids = TRUE.  These arguments allow one to include a vector to label points and a logical statement to
 #'  include warpgrids, respectively.  Warpgrids can only be included for 3D arrays of Procrustes residuals. The plot is a plot of PLS scores from 
 #'  Block1 versus Block2 performed for the first set of PLS axes. 
 #'  
+#' \subsection{Similarity to \code{\link{two.b.pls}} and \code{\link{compare.pls}} }{ 
+#' Note that \code{integration.test} performed on two matrices or arrays returns the same results as \code{\link{two.b.pls}}.  
+#' However,  \code{\link{two.b.pls}} is limited to only two modules.  It might be of interest with 3+ modules to perform integration tests
+#' between all pairwise comaprisons of modules.  This can be done, test by test, and the levels of integration can be compared with
+#' \code{\link{compare.pls}}.  Such results are different than using the average amount of integration, as performed by \code{integration.test}
+#' when more than two modules are input.
+#' }
+#' 
+#'  \subsection{Using phylogenies and PGLS}{ 
+#' If one wishes to incorporate a phylogeny, \code{\link{phylo.integration}} is the function to use.  This function is exactly the same as \code{integration.test}
+#' but allows PGLS estimation of PLS vectors.  Because \code{\link{integration.test}} can be used on two blocks, \code{\link{phylo.integration}} likewise allows one to
+#' perform a phylogenetic two-block PLS analysis.
+#' }
+#'  
+#'  \subsection{Notes for geomorph 3.0.4 and subsequent versions}{ 
+#'  Compared to previous versions of geomorph, users might notice differences in effect sizes.  Previous versions used z-scores calculated with 
+#'  expected values of statistics from null hypotheses (sensu Collyer et al. 2015); however Adams and Collyer (2016) showed that expected values 
+#'  for some statistics can vary with sample size and variable number, and recommended finding the expected value, empirically, as the mean from the set 
+#'  of random outcomes.  Geomorph 3.0.4 and subsequent versions now center z-scores on their empirically estimated expected values and where appropriate, 
+#'  log-transform values to assure statistics are normally distributed.  This can result in negative effect sizes, when statistics are smaller than 
+#'  expected compared to the avergae random outcome.  For ANOVA-based functions, the option to choose among different statistics to measure effect size 
+#'  is now a function argument.
+#' }
+#' 
 #' @param A A 3D array (p x k x n) containing GPA-aligned coordinates for all specimens, or a matrix (n x variables)
 #' @param A2 An optional 3D array (p x k x n) containing GPA-aligned coordinates for all specimens, or a matrix (n x variables) for a second partition
 #' @param partition.gp A list of which landmarks (or variables) belong in which partition (e.g. A,A,A,B,B,B,C,C,C) (required when only 1 dataset provided)
@@ -54,7 +78,7 @@
 #'   (for 2 modules only).}
 #'    \item{YScores}{Values of right (y) block projected onto singular vectors
 #'   (for 2 modules only).}
-#'   \item{svd}{The singular value decomposition of the cross-covariances (for 2 modules only).}
+#'    \item{svd}{The singular value decomposition of the cross-covariances (for 2 modules only).}
 #'    \item{A1}{Input values for the left block (for 2 modules only).}
 #'    \item{A2}{Input values for the right block (for 2 modules only).}
 #'    \item{A1.matrix}{Left block (matrix) found from A1 (for 2 modules only).}
@@ -64,8 +88,12 @@
 #' @references  Bookstein, F. L., P. Gunz, P. Mitteroecker, H. Prossinger, K. Schaefer, and H. Seidler. 
 #'   2003. Cranial integration in Homo: singular warps analysis of the midsagittal plane in ontogeny and 
 #'   evolution. J. Hum. Evol. 44:167-187.
-#' @seealso \code{\link{two.b.pls}}, \code{\link{modularity.test}}, \code{\link{phylo.pls}}, and 
-#' \code{\link{phylo.integration}}
+#' @references Collyer, M.L., D.J. Sekora, and D.C. Adams. 2015. A method for analysis of phenotypic change for phenotypes described 
+#' by high-dimensional data. Heredity. 115:357-365.
+#' @references Adams, D.C. and M.L. Collyer. 2016.  On the comparison of the strength of morphological integration across morphometric 
+#' datasets. Evolution. 70:2623-2631.
+#' @seealso \code{\link{two.b.pls}}, \code{\link{modularity.test}}, \code{\link{phylo.pls}}, 
+#' \code{\link{phylo.integration}}, and \code{\link{compare.pls}}
 #' @examples
 #' data(plethodon) 
 #' Y.gpa<-gpagen(plethodon$land)    #GPA-alignment    
@@ -111,10 +139,20 @@ integration.test<-function(A, A2=NULL,partition.gp=NULL,iter=999, seed=NULL, pri
     ngps=2; n<-dim(x)[2]
   }
   if(ngps==2){
+    pls.obs <- pls(x, y, verbose=TRUE)
+    if(NCOL(x) > NROW(x)){
+      pcax <- prcomp(x)
+      d <- which(zapsmall(pcax$sdev) > 0)
+      x <- pcax$x[,d]
+    }
+    if(NCOL(y) > NROW(y)){
+      pcay <- prcomp(y)
+      d <- which(zapsmall(pcay$sdev) > 0)
+      y <- pcay$x[,d]
+    }
     if(print.progress) pls.rand <- apply.pls(center(x), center(y), iter=iter, seed=seed) else
       pls.rand <- .apply.pls(center(x), center(y), iter=iter, seed=seed)
-    pls.obs <- pls(x, y, verbose=TRUE)
-    p.val <- pval(pls.rand)
+    p.val <- pval(abs(pls.rand))
     XScores <- pls.obs$XScores
     YScores <- pls.obs$YScores
   }
@@ -122,7 +160,7 @@ integration.test<-function(A, A2=NULL,partition.gp=NULL,iter=999, seed=NULL, pri
     pls.obs <- plsmulti(x, gps)  
     if(print.progress) pls.rand <- apply.plsmulti(center(x), gps, iter=iter, seed=seed) else
       pls.rand <- .apply.plsmulti(center(x), gps, iter=iter, seed=seed)
-    p.val <- pval(pls.rand)
+    p.val <- pval(abs(pls.rand))
   }  
   ####OUTPUT
   if(ngps > 2) r.pls.mat <- pls.obs$r.pls.mat else r.pls.mat <- NULL
@@ -141,6 +179,7 @@ integration.test<-function(A, A2=NULL,partition.gp=NULL,iter=999, seed=NULL, pri
   }
   if(ngps>2){
     out <- list(r.pls = pls.obs$r.pls, r.pls.mat = r.pls.mat, P.value = p.val,
+                random.r = pls.rand, 
                 permutations = iter+1, call=match.call(),
                 method = "PLS")
   }
