@@ -115,18 +115,18 @@ modularity.test<-function(A,partition.gp,iter=999, CI=FALSE,seed=NULL, print.pro
     if(print.progress){
       cat("\nFinding the optimal rotation for CR\n")
       pb <- txtProgressBar(min = 0, max = length(rot.mat), initial = 0, style=3) 
-      rotatedCRs <-sapply(1:length(rot.mat), function(j) {
+     rotatedCRs <- sapply(1:length(rot.mat), function(j) {
         r <- rot.mat[[j]]
         rotA <- t(mapply(function(a) matrix(t(a%*%r)), Alist))
         setTxtProgressBar(pb,j)
-        CR(rotA, gps=gps.obs)$CR
+        quick.CR(rotA, gps=gps.obs)
       })
       close(pb)
     } else {
       rotatedCRs <-sapply(1:length(rot.mat), function(j) {
         r <- rot.mat[[j]]
         rotA <- t(mapply(function(a) matrix(t(a%*%r)), Alist))
-        CR(rotA, gps=gps.obs)$CR
+        quick.CR(rotA, gps=gps.obs)
       })
     }
     avgCR <- mean(rotatedCRs)
@@ -141,7 +141,7 @@ modularity.test<-function(A,partition.gp,iter=999, CI=FALSE,seed=NULL, print.pro
     if(print.progress) {
       cat("\nPerforming permutations\n")
       CR.rand <- apply.CR(x, gps, k=k, iter=iter, seed=seed)
-    } else CR.rand <- .apply.CR(x, gps, k=k, iter=iter, seed=seed)
+      } else CR.rand <- .apply.CR(x, gps, k=k, iter=iter, seed=seed)
     CR.rand[1] <- CR.obs <- avgCR
     if(ngps > 2) CR.mat <- CR(x,gps.obs)$CR.mat else CR.mat <- NULL
     p.val <- pval(1/CR.rand)  #b/c smaller values more significant
