@@ -17,12 +17,35 @@
 #'  include warpgrids, respectively.  Warpgrids can only be included for 3D arrays of Procrustes residuals. The plot is a plot of PLS scores from 
 #'  Block1 versus Block2 performed for the first set of PLS axes. 
 #'  
+#'  \subsection{For more than two blocks}{ 
+#' If one wishes to consider 3+ arrays or matrices, there are multiple options.  First, one could perform multiple two.b.pls analyses and use
+#' \code{\link{compare.pls}} to ascertain which blocks are more "integrated".  Second, one could use \code{\link{integration.test}} and perform a test that
+#' averages the amount of integration (correlations) across multiple pairwise blocks.  Note that \code{\link{integration.test}} performed on two matrices or
+#' arrays returns the same results as two.b.pls.  (Thus, \code{\link{integration.test}} is more flexible and thorough.)
+#' }
+#' 
+#'  \subsection{Using phylogenies and PGLS}{ 
+#' If one wishes to incorporate a phylogeny, \code{\link{phylo.integration}} is the function to use.  This function is exactly the same as \code{\link{integration.test}}
+#' but allows PGLS estimation of PLS vectors.  Because \code{\link{integration.test}} can be used on two blocks, \code{\link{phylo.integration}} likewise allows one to
+#' perform a phylogenetic two-block PLS analysis.
+#' }
+#'  
 #'  \subsection{Notes for geomorph 3.0}{ 
 #' There is a slight change in two.b.pls plots with geomorph 3.0.  Rather than use the shapes of specimens that matched minimum and maximum PLS
 #' scores, major-axis regression is used and the extreme fitted values are used to generate deformation grids.  This ensures that shape deformations
 #' are exactly along the major axis of shape covariation.  This axis is also shown as a best-fit line in the plot.
 #' }
 #' 
+#'  \subsection{Notes for geomorph 3.0.4 and subsequent versions}{ 
+#'  Compared to previous versions of geomorph, users might notice differences in effect sizes.  Previous versions used z-scores calculated with 
+#'  expected values of statistics from null hypotheses (sensu Collyer et al. 2015); however Adams and Collyer (2016) showed that expected values 
+#'  for some statistics can vary with sample size and variable number, and recommended finding the expected value, empirically, as the mean from the set 
+#'  of random outcomes.  Geomorph 3.0.4 and subsequent versions now center z-scores on their empirically estimated expected values and where appropriate, 
+#'  log-transform values to assure statistics are normally distributed.  This can result in negative effect sizes, when statistics are smaller than 
+#'  expected compared to the avergae random outcome.  For ANOVA-based functions, the option to choose among different statistics to measure effect size 
+#'  is now a function argument.
+#' }
+#' 
 #' @param A1 A 3D array (p x k x n) containing GPA-aligned coordinates for the first block, or a matrix (n x variables)
 #' @param A2 A 3D array (p x k x n) containing GPA-aligned coordinates for the second block, or a matrix (n x variables)
 #' @param iter Number of iterations for significance testing
@@ -37,7 +60,8 @@
 #' @author Dean Adams and Michael Collyer
 #' @return Object of class "pls" that returns a list of the following:
 #'   \item{r.pls}{The correlation coefficient between scores of projected values on the first
-#'   singular vectors of left (x) and right (y) blocks of landmarks (or other variables)}
+#'   singular vectors of left (x) and right (y) blocks of landmarks (or other variables).  This value can only be negative
+#'   if single variables are input, as it reduces to the Pearson correlation coefficient.}
 #'   \item{P.value}{The empirically calculated P-value from the resampling procedure.}
 #'   \item{left.pls.vectors}{The singular vectors of the left (x) block}
 #'   \item{right.pls.vectors}{The singular vectors of the right (y) block}
@@ -45,7 +69,7 @@
 #'   resampling procedure.}
 #'   \item{XScores}{Values of left (x) block projected onto singular vectors.}
 #'   \item{YScores}{Values of right (y) block projected onto singular vectors.}
-#'   \item{svd}{The singular value decomposition of the cross-covariances.}
+#'   \item{svd}{The singular value decomposition of the cross-covariances.  See \code{\link{svd}} for further details.}
 #'   \item{A1}{Input values for the left block.}
 #'   \item{A2}{Input values for the right block.}
 #'   \item{A1.matrix}{Left block (matrix) found from A1.}
@@ -53,10 +77,14 @@
 #'   \item{permutations}{The number of random permutations used in the resampling procedure.}
 #'   \item{call}{The match call.}
 #'   
-#' @seealso \code{\link{integration.test}}, \code{\link{modularity.test}}, \code{\link{phylo.pls}}, and 
-#' \code{\link{phylo.integration}}
+#' @seealso \code{\link{integration.test}}, \code{\link{modularity.test}}, \code{\link{phylo.pls}},  
+#' \code{\link{phylo.integration}}, and \code{\link{compare.pls}}
 #' @references  Rohlf, F.J., and M. Corti. 2000. The use of partial least-squares to study covariation in shape. 
 #' Systematic Biology 49: 740-753.
+#' @references Collyer, M.L., D.J. Sekora, and D.C. Adams. 2015. A method for analysis of phenotypic change for phenotypes described 
+#' by high-dimensional data. Heredity. 115:357-365.
+#' @references Adams, D.C. and M.L. Collyer. 2016.  On the comparison of the strength of morphological integration across morphometric 
+#' datasets. Evolution. 70:2623-2631.
 #' @examples
 #' data(plethShapeFood) 
 #' Y.gpa<-gpagen(plethShapeFood$land)    #GPA-alignment    
@@ -77,12 +105,22 @@ two.b.pls <- function (A1, A2,  iter = 999, seed = NULL, print.progress=TRUE){
   if (nrow(x) != nrow(y)) stop("Data matrices have different numbers of specimens.")
   if (!is.null(rownames(x))  && !is.null(rownames(y))) {y <- y[rownames(x), ] }
   n <- nrow(x)
-  if(print.progress) pls.rand <- apply.pls(center(x), center(y), RV=FALSE, iter=iter, seed=seed) else
-    pls.rand <- .apply.pls(center(x), center(y), RV=FALSE, iter=iter, seed=seed) 
   pls.obs <- pls(x, y, RV=FALSE, verbose=TRUE)
   rownames(pls.obs$pls.svd$u) <- colnames(x)
   rownames(pls.obs$pls.svd$v) <- colnames(pls.obs$pls.svd$vt) <- colnames(y)
-  p.val <- pval(pls.rand)
+  if(NCOL(x) > n){
+    pcax <- prcomp(x)
+    d <- which(zapsmall(pcax$sdev) > 0)
+    x <- pcax$x[,d]
+  }
+  if(NCOL(y) > n){
+    pcay <- prcomp(y)
+    d <- which(zapsmall(pcay$sdev) > 0)
+    y <- pcay$x[,d]
+  }
+  if(print.progress) pls.rand <- apply.pls(center(x), center(y), RV=FALSE, iter=iter, seed=seed) else
+    pls.rand <- .apply.pls(center(x), center(y), RV=FALSE, iter=iter, seed=seed) 
+  p.val <- pval(abs(pls.rand))
   XScores <- pls.obs$XScores
   YScores <- pls.obs$YScores
   out <- list(r.pls = pls.rand[1], P.value = p.val,
